@@ -8,9 +8,8 @@ from robotlibcore import DynamicCore
 
 from RPA.Windows.keywords import (
     ActionKeywords,
-    ControlKeywords,
+    ElementKeywords,
     LocatorKeywords,
-    RecorderKeywords,
     WindowKeywords,
 )
 
@@ -26,8 +25,15 @@ class Windows(DynamicCore):
 
     **About terminology**
 
-    The most used term in uiautomation package is "Control" which in the library context
-    maps to objects of the application like for example Window, Button or ListItem.
+    ***ControlType***
+
+    Value referred to by locator keys `type:` or `control`. Represents type of application
+    object, which can be e.g. `Window`, `Button` or `ListItem`.
+
+    ***Element***
+
+    Entity of an application structure (e.g. certain button in a window), which can be
+    identified by a locator.
 
     **Locators**
 
@@ -49,8 +55,9 @@ class Windows(DynamicCore):
     index           foundIndex (int)
     offset          offset coordinates (x (int), y (int)) from control center
     executable      target window by its executable name
+    handle          target window handle (int)
     desktop         target desktop
-    process         target window by its executable's process id
+    process         *NOT YET SUPPORTED* target window by its executable's process id
     depth           searchDepth (int) for finding Control (default 8)
     =============== =======================
 
@@ -95,26 +102,9 @@ class Windows(DynamicCore):
 
     **Recording**
 
-    Library provides some rudimentary keywords for inspecting and recording locators for
-    Control objects.
-
-    Keyword ``Inspect Element`` will return list of steps that can be used to interact with Control object.
-
-    Recording can be activated by ``Start Recording`` which then activate mode where upon mouse click
-    Control under mouse pointer will be inspected. Recording can be stopped at any time by keyboard `ESC`.
-    After recording has been stopped, the recorded steps can be retrieved by keyword ``Get Recording``.
-
-    Example task for the recording
-
-    .. code-block:: robotframework
-
-        *** Tasks ***
-        Record Task
-            Log To Console    Record steps for the Task
-            Start Recording
-            ${recording}=    Get Recording    sleeps=${FALSE}
-            Log To Console    ${recording}
+    The package provides some rudimentary inspecting and recording via script SCRIPT_NAME
 
+    ADD GUIDE HERE
 
     **Examples**
 
@@ -137,7 +127,7 @@ class Windows(DynamicCore):
             Control Window    name:Calculator
             Click    id:clearButton
             Send Keys   96+4=
-            ${result}=    Get Control Property    id:CalculatorResults    name
+            ${result}=    Access Attribute or Method    id:CalculatorResults    Name
             Log To Console    n${result}
 
 
@@ -152,14 +142,13 @@ class Windows(DynamicCore):
         self.timeout = 0.5
         self.simulate_move = False
         self.window = None
-        self.control_anchor = None
+        self.anchor_element = None
 
         # Register keyword libraries to LibCore
         libraries = [
             ActionKeywords(self),
-            ControlKeywords(self),
+            ElementKeywords(self),
             LocatorKeywords(self),
-            RecorderKeywords(self),
             WindowKeywords(self),
         ]
         super().__init__(libraries)
